@@ -11,22 +11,21 @@ my $graph = Gtk2::Ex::Graph::GD->new(500, 300, 'bars');
 # All the properties set here go straight into the GD::Graph::* object created inside.
 # Therefore, any property acceptable to the GD::Graph::* object can be passed through here
 $graph->set (
-	x_label         => 'TRE Label',
-	y_label         => 'Y label',
-	title           => 'A Simple Bar Chart',
-	x_labels_vertical => 1,
+	title           => 'Mice, Fish and Lobsters',
+	x_labels_vertical => TRUE,
 	bar_spacing     => 1,
 	shadowclr       => 'dred',
 	transparent     => 0,
 );
 
-my @legend_keys = ('First', 'Second');
+my @legend_keys = ('Field Mice Population', 'Fish Population', 'Lobster Growth in millions');
 $graph->set_legend(@legend_keys);
 
 my $data = GD::Graph::Data->new([
-    ["1st","2nd","3rd","4th","5th","6th","7th", "8th", "9th"],
-    [    1,    2,    5,    6,    3,  1.5,    1,     3,     4],
-    [    1.4,  4,   15,    6,    13,  1.5,    11,     3,     4],
+    [ 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,],
+    [  1,  2,  5, 8,  3, 4.5,  1, 3,  4],
+    [1.4,  4, 15, 6, 13, 1.5, 11, 3,  4],
+    [11.4,  14, 22, 16, 1.3, 15, 1, 13,  14],
 ]) or die GD::Graph::Data->error;
 
 # This actually returns an eventbox instead of an image. 
